@@ -385,7 +385,6 @@ void FolderView::init()
     m_alignToGrid         = cg.readEntry("alignToGrid", false);
     m_clickToView         = cg.readEntry("clickForFolderPreviews", true);
     m_previewPlugins      = cg.readEntry("previewPlugins", QStringList() << "imagethumbnail" << "jpegthumbnail");
-    m_customIconSize      = cg.readEntry("customIconSize", 0);
     m_sortDirsFirst       = cg.readEntry("sortDirsFirst", true);
     m_sortColumn          = cg.readEntry("sortColumn", int(KDirModel::Name));
     m_sortOrder           = sortOrderStringToEnum(cg.readEntry("sortOrder", "ascending"));
@@ -491,9 +490,8 @@ void FolderView::configChanged()
         needReload = true;
     }
     //Reload m_customIconSize values
-    const int size = m_customIconSize;
     m_customIconSize = cg.readEntry("customIconSize", m_customIconSize);
-    if (size != iconSize().width()) {
+    if (m_customIconSize != iconSize().width()) {
         needReload = true;
     }
 
@@ -625,8 +623,7 @@ void FolderView::configChanged()
 
 FolderView::~FolderView()
 {
-    if (m_dialog)
-        delete m_dialog;
+    delete m_dialog;
     delete m_newMenu;
 }
 
@@ -769,21 +766,21 @@ void FolderView::createConfigurationInterface(KConfigDialog *parent)
     uiDisplay.numLinesEdit->setValue(m_numTextLines);
     uiDisplay.colorButton->setColor(textColor());
 
-    for (int i = 0; i < uiDisplay.sortCombo->maxCount(); i++) {
+    for (int i = 0; i < uiDisplay.sortCombo->count(); i++) {
        if (m_sortColumn == uiDisplay.sortCombo->itemData(i).toInt()) {
            uiDisplay.sortCombo->setCurrentIndex(i);
            break;
        }
     }
 
-    for (int i = 0; i < uiDisplay.flowCombo->maxCount(); i++) {
+    for (int i = 0; i < uiDisplay.flowCombo->count(); i++) {
        if (m_flow == uiDisplay.flowCombo->itemData(i).value<IconView::Flow>()) {
            uiDisplay.flowCombo->setCurrentIndex(i);
            break;
        }
     }
 
-    for (int i = 0; i < uiFilter.filterCombo->maxCount(); i++) {
+    for (int i = 0; i < uiFilter.filterCombo->count(); i++) {
        if (m_filterType == uiFilter.filterCombo->itemData(i).value<ProxyModel::FilterMode>()) {
            uiFilter.filterCombo->setCurrentIndex(i);
            break;
@@ -1970,6 +1967,15 @@ void FolderView::indexesMoved(const QModelIndexList &indexes)
         updateSortActionsState();
         config().writeEntry("sortColumn", m_sortColumn);
         emit configNeedsSaving();
+
+        if (isUserConfiguring()) {
+            for (int i = 0; i < uiDisplay.sortCombo->count(); i++) {
+                if (m_sortColumn == uiDisplay.sortCombo->itemData(i).toInt()) {
+                    uiDisplay.sortCombo->setCurrentIndex(i);
+                    break;
+                }
+            }
+        }
     }
 
     m_delayedSaveTimer.start(5000, this);
